]> sigrok.org Git - libsigrok.git/blobdiff - session.c
sr: fx2lafw: Forgot to add (C) line to fx2lafw.h in recent commit.
[libsigrok.git] / session.c
index 8048fdfd7b22e00dc3294395076d23b8672a0dd4..f1a8370bf48784641973a978ae5ba45a28f110bb 100644 (file)
--- a/session.c
+++ b/session.c
@@ -97,7 +97,7 @@ SR_API int sr_session_destroy(void)
  *
  * @return SR_OK upon success, SR_ERR_BUG if no session exists.
  */
-SR_API int sr_session_dev_clear(void)
+SR_API int sr_session_dev_remove_all(void)
 {
        if (!session) {
                sr_err("session: %s: session was NULL", __func__);
@@ -159,11 +159,11 @@ SR_API int sr_session_dev_add(struct sr_dev *dev)
 }
 
 /**
* Clear all datafeed callbacks in the current session.
  *
  * @return SR_OK upon success, SR_ERR_BUG if no session exists.
  */
-SR_API int sr_session_datafeed_callback_clear(void)
+SR_API int sr_session_datafeed_callback_remove_all(void)
 {
        if (!session) {
                sr_err("session: %s: session was NULL", __func__);
@@ -159,11 +159,11 @@ SR_API int sr_session_dev_add(struct sr_dev *dev)
 
 /**
- * Clear all datafeed callbacks in the current session.
+ * Remove all datafeed callbacks in the current session.
  *
  * @return SR_OK upon success, SR_ERR_BUG if no session exists.